<?php

namespace Pinpoint\CarouselManager\Controller\Adminhtml\Carousel;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Registry;
use Magento\Framework\View\Result\PageFactory;
use Pinpoint\CarouselManager\Model\CarouselRepository;

/**
 * Class CarouselList
 * @package Pinpoint\CarouselManager
 */
class Edit extends Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Pinpoint_CarouselManager::carousel';

    /**
     * @var PageFactory
     */
    protected $resultPageFactory;

    /**
     * @var Registry
     */
    protected $_coreRegistry;

    /**
     * @var Carousel
     */
    protected $carouselRepository;

    /**
     * Edit constructor.
     * @param Context $context
     * @param PageFactory $resultPageFactory
     * @param Registry $coreRegistry
     * @param CarouselRepository $carouselRepository
     */
    public function __construct(
        Context $context,
        PageFactory $resultPageFactory,
        Registry $coreRegistry,
        CarouselRepository $carouselRepository
    )
    {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->_coreRegistry = $coreRegistry;
        $this->carouselRepository = $carouselRepository;
    }

    /**
     * @return mixed
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('carousel_id');

        if ($id) {
            try {
                $model = $this->carouselRepository->getById($id);
                if (!$model->getId()) {
                    $this->messageManager->addErrorMessage(__('This carousel no longer exists.'));
                    /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
                    $resultRedirect = $this->resultRedirectFactory->create();
                    return $resultRedirect->setPath('*/*/');
                }
                $this->_coreRegistry->register('carousel', $model);
            } Catch (\Exception $e) {
                $this->messageManager->addErrorMessage($e->getMessage());
            }

        }

        return $this->resultPageFactory->create();
    }
}
